@@ -68,11 +68,21 @@ def slackNotifyMessage(channel, webhook, msg):
     return response
 
 def lambda_handler(event, context):
-
     event_name = event.get('detail').get('eventName', 'eventName_notfound')
     region = event.get('detail').get('awsRegion', 'awsRegion_notfound')
     source_ip = event.get('detail').get('sourceIPAddress', 'sourceIPAddress_notfound')
-    user_name = event.get('detail').get('userIdentity').get('userName', 'userName_notfound')
+    ## Check user_identity and type
+    user_identity = event.get('detail').get('userIdentity')
+    user_identity_type = event.get('detail').get('userIdentity').get('type')
+    user_name = 'None'
+    if user_identity_type == 'IAMUser':
+        user_name = user_identity.get('userName', 'userName_notfound')
+    elif user_identity_type == 'AssumedRole':
+        user_name = user_identity.get('principalId', 'userName_notfound')
+    elif user_identity_type == 'Root':
+        user_name = user_identity.get('arn', 'root_name_notfound')
+    else:
+        user_name = f"{user_identity.get('userName')} {user_identity.get('principalId')} {user_identity.get('arn')}"
     account_id = event.get('account', 'account_notfound')
     response_elements = event.get('detail').get('responseElements', 'responseElements_notfound')
 
@@ -126,5 +136,4 @@ def lambda_handler(event, context):
                 slackNotifyMessage(os.environ.get('SLACK_CHANNEL_NAME'), os.environ.get('SLACK_WEBHOOK_URL'), msg)
         if event_name == 'ConsoleLogin':
             msg = msg
-            slackNotifyMessage(os.environ.get('SLACK_CHANNEL_NAME'), os.environ.get('SLACK_WEBHOOK_URL'), msg)
-        
\ No newline at end of file
+            slackNotifyMessage(os.environ.get('SLACK_CHANNEL_NAME'), os.environ.get('SLACK_WEBHOOK_URL'), msg)
\ No newline at end of file
