@@ -10,19 +10,11 @@ import typing_extensions
 
 from typeguard import check_type
 
-import aws_cdk.assertions._jsii
-import aws_cdk.aws_events._jsii
-import aws_cdk.aws_events_targets._jsii
-import aws_cdk.aws_lambda._jsii
-import aws_cdk.aws_logs._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-events-notify",
-    "1.0.489",
-    __name__[0:-6],
-    "cdk-events-notify@1.0.489.jsii.tgz",
+    "cdk-events-notify", "2.2.55", __name__[0:-6], "cdk-events-notify@2.2.55.jsii.tgz"
 )
 
 __all__ = [
